@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  bln.rb - a easyballoon compatible Saori module for ninix
-#  Copyright (C) 2002-2017 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2002-2018 by Shyouzou Sugitani <shy@users.osdn.me>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -346,9 +346,9 @@ module Bln
         @font_desc = Pango::FontDescription.new
         @font_desc.set_family('Sans')
         if data.include?('font.bold') and data['font.bold'] == 'on'
-          @font_desc.set_weight(Pango::Weight::BOLD)
+          @font_desc.set_weight(:bold)
         end
-        @layout.set_wrap(Pango::WrapMode::CHAR)
+        @layout.set_wrap(:char)
         set_layout()
       end
       if data.include?('slide.vx')
@@ -468,7 +468,6 @@ module Bln
       h = @balloon_surface.height
       w = [8, (w * @scale / 100).to_i].max
       h = [8, (h * @scale / 100).to_i].max
-      @window.update_size(w, h)
       @base_x, @base_y = get_coordinate(w, h)
     end
 
@@ -756,17 +755,15 @@ module Bln
     end
 
     def redraw(widget, cr)
-      scale = @scale
-      cr.scale(scale / 100.0, scale / 100.0)
-      cr.set_source(@balloon_surface, 0, 0)
-      cr.set_operator(Cairo::OPERATOR_SOURCE)
-      cr.paint()
+      @window.set_surface(cr, @balloon_surface, @scale)
       cr.set_operator(Cairo::OPERATOR_OVER) # restore default
+      cr.translate(*@window.get_draw_offset) # XXX
       unless @layout.nil?
         cr.set_source_rgb(*@fontcolor)
         cr.move_to(@left.to_i, @top.to_i)
         cr.show_pango_layout(@layout)
       end
+      @window.set_shape(cr)
     end
 
     def get_state
