@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  hanayu.rb - a "花柚" compatible Saori module for ninix
-#  Copyright (C) 2002-2017 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2002-2018 by Shyouzou Sugitani <shy@users.osdn.me>
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -355,7 +355,7 @@ module Hanayu
       default_gravity = context.base_gravity # XXX
       context.base_gravity = Pango::Gravity::EAST # Vertical Text
       layout.set_text(@title)
-      layout.set_wrap(Pango::WrapMode::WORD)
+      layout.set_wrap(:word)
       tw, th = layout.pixel_size
       cr.move_to(58, w - 20 - th)
       cr.show_pango_layout(layout)
