@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2003-2017 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2003-2018 by Shyouzou Sugitani <shy@users.osdn.me>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -388,7 +388,7 @@ module Menu
       end
     end
 
-    def popup(button, side)
+    def popup(side)
       @__popup_menu.unrealize()
       for key in @__menu_list.keys
         item = @__menu_list[key][:entry]
@@ -437,8 +437,7 @@ module Menu
           end
         end
       end
-      @__popup_menu.popup(nil, nil, button,
-                          Gtk.current_event_time())
+      @__popup_menu.popup_at_pointer(nil)
     end
 
     def __set_caption(name, caption)
