@@ -2,7 +2,7 @@
 #
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2004-2017 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2004-2018 by Shyouzou Sugitani <shy@users.osdn.me>
 #  Copyright (C) 2003-2005 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -330,7 +330,7 @@ module Prefs
       scrolled.set_shadow_type(Gtk::ShadowType::ETCHED_IN)
       box.pack_start(scrolled, :expand => true, :fill => true, :padding => 0)
       scrolled.show()
-      treeview = Gtk::TreeView.new(nil)
+      treeview = Gtk::TreeView.new()
       column = Gtk::TreeViewColumn.new(_('Balloon Name'),
                                        Gtk::CellRendererText.new(),
                                        :text => 0)
